@@ -71,7 +71,7 @@ usage() {
     echo ""
 }
 
-NVIDIA_BUG_REPORT_CHANGE='$Change: 28893081 $'
+NVIDIA_BUG_REPORT_CHANGE='$Change: 30146290 $'
 NVIDIA_BUG_REPORT_VERSION=`echo "$NVIDIA_BUG_REPORT_CHANGE" | tr -c -d "[:digit:]"`
 
 # Set the default filename so that it won't be empty in the usage message
@@ -481,6 +481,22 @@ if [ -d "/var/lib/dkms/nvidia" ]; then
     done
 fi
 
+# check the status of the nvidia-suspend, nvidia-hibernate, and nvidia-resume
+# systemd services
+
+systemctl=`which systemctl 2> /dev/null | head -n 1`
+
+if [ $? -eq 0 -a -x "$systemctl" ]; then
+    cmd="$systemctl status nvidia-suspend.service nvidia-hibernate.service nvidia-resume.service"
+    (
+        echo "____________________________________________"
+        echo ""
+        echo "$cmd"
+        $cmd
+        echo ""
+    ) 2> /dev/null | $GZIP_CMD >> $LOG_FILENAME
+fi
+
 # use systemd's journalctl to capture X logs where applicable
 
 journalctl=`which journalctl 2> /dev/null | head -n 1`
